from lunas import Iterator
from lunas.readers.nested import Enumerate
from lunas.readers.range import Range, Count

d1 = Range(10, )
d2 = Count(3, bufsize=1)
d = Enumerate(d1, 1)
it = Iterator(d, 3, cache_size=1000, sample_size_fn=lambda x: x[0], sort_cache_by=lambda x: -x[0])
outputs = []
for x in it.iter_epoch():
    print(x.data)
    outputs.append(x.data)

for x in sorted(outputs, key=lambda x: x[0][0]):
    print(x)



from lunas import Range, Shuffle, Iterator, GroupIterator, Distributed

x = Range(22)
x = Shuffle(x)

import numpy

world = 3
for r in range(world):
    print('---', r)
    numpy.random.seed(100)
    y = Distributed(x, world, r)
    it = GroupIterator(Iterator(y, 1), 4)
    for batch in it.iter_epoch():
        print([b.data for b in batch])
        print(len(batch))
    # for b in y:
    #     print(b)
#
# x=list(range(11))
# print(x[9:None:3])
